Module blaxel.core.client.models.serverless_config
==================================================

Classes
-------

`ServerlessConfig(configuration: blaxel.core.client.types.Unset | ForwardRef('ServerlessConfigConfiguration') = <blaxel.core.client.types.Unset object>, max_retries: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, max_scale: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, min_scale: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>, timeout: blaxel.core.client.types.Unset | int = <blaxel.core.client.types.Unset object>)`
:   Configuration for a serverless deployment
    
    Attributes:
        configuration (Union[Unset, ServerlessConfigConfiguration]): The configuration for the deployment
        max_retries (Union[Unset, int]): The maximum number of retries for the deployment
        max_scale (Union[Unset, int]): The minimum number of replicas for the deployment. Can be 0 or 1 (in which case
            the deployment is always running in at least one location).
        min_scale (Union[Unset, int]): The maximum number of replicas for the deployment.
        timeout (Union[Unset, int]): The timeout for the deployment in seconds
    
    Method generated by attrs for class ServerlessConfig.

    ### Static methods

    `from_dict(src_dict: dict[str, typing.Any]) ‑> ~T`
    :

    ### Instance variables

    `additional_keys: list[str]`
    :

    `additional_properties`
    :

    `configuration`
    :

    `max_retries`
    :

    `max_scale`
    :

    `min_scale`
    :

    `timeout`
    :

    ### Methods

    `to_dict(self) ‑> dict[str, typing.Any]`
    :